/*
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: formulaire
 * Version: 1.08.00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
(function ($) {
    'use strict';
    var $kformPanel = $('[data-panel="kform"]'),
        $datagridToolbox = $('.js-form-datatable'),
        $formInputs = $('input, select', $kformPanel).not('[id="forms_check-all"]'),
        $formStyle = $('select[name="STYLE"]', $kformPanel);

    function buildTag() {
        var style = $formStyle.val();
        if (style === 'E') {
            var $checkboxes = $('.js-forms__list input[type=checkbox]:checked:not([id="forms_check-all"])'),
                value = '';
            $checkboxes.each(
                function () {
                    value += $(this).val();
                });
            return value;
        } else {
            var tagValue = '[formulaire;',
                code = $('input[name="CODE"]:checked', $kformPanel).val();
            if (!code || !style || style === '0000') {
                return null;
            }
            tagValue += 'CODE=' + code;
            tagValue += '&STYLE=' + style;
            return tagValue + ']';
        }
    }

    function buildAndSendTagValue() {
        var tagValue = buildTag();
        if (tagValue) {
            if ($formStyle.val() === 'E') {
                COMMONS_MESSAGES.postMessageToParent(
                    {
                        'tag': 'kform',
                        'value': tagValue,
                        'noFake' : true
                    });
            } else {
                COMMONS_MESSAGES.postMessageToParent(
                    {
                        'tag': 'kform',
                        'value': tagValue
                    });
            }
        } else {
            COMMONS_MESSAGES.postMessageToParent('erase');
        }
    }

    function buildField(index, label, code, info) {
        var $li = $('<li>'),
            value = '[cf;' + $('input[name="CODE"]:checked', $kformPanel).val() + ';E;' + code + ']';
        $('<input id="form-field-' + index + '" type="checkbox" value="' + value + '" checked>').appendTo($li);
        $('<label for="form-field-' + index + '">' + label + '</label>').appendTo($li);
        if (info) {
            var $bubble = $('<button type="button" class="infobulle" data-original-title="' + info + '"></button>').tooltip(
                {
                    html: false,
                    placement: 'right',
                    trigger: 'hover focus'
                });
            $bubble.appendTo($li);
        }
        return $li;
    }

    function buildForm() {
        var model = JSON.parse($('input:checked', $datagridToolbox).attr('data-model')),
            nbFields = $.parseInteger(model.LISTE_NB_CHAMPS),
            $formList = $('.js-forms__list');
        $('li:not(:first)', $formList).remove();
        $('li:first > input', $formList).prop('checked', true);
        var $firstField = buildField(0, 'Début du formulaire', 'DEBUT', 'Ne décochez cette case que si une balise &lt;form&gt; est introduite en amont.');
        $firstField.appendTo($formList);
        var i = 0;
        for (; i < nbFields; i++) {
            var fieldName = 'CHAMP' + i,
                $field = buildField(i + 1, model[fieldName + '_LIBELLE'], model[fieldName + '_CODE']);
            $field.appendTo($formList);
        }
        var $lastField = buildField(++i, 'Fin du formulaire', 'FIN', 'Ne décochez cette case que si une balise &lt;/form&gt; est introduite en aval.');
        $lastField.appendTo($formList);
    }

    function updateForm() {
        var $formElements = $('.js-forms__elements', $kformPanel);
        if ($formStyle.val() === 'E') {
            $formElements.removeClass('masquer');
            buildForm();
        } else {
            $formElements.addClass('masquer');
        }
        buildAndSendTagValue();
    }

    // Bind 'click' events on datatable rows
    function bindDataTableRows() {
        $('tbody', $datagridToolbox).on(
            'click', 'tr', function () {
                var $this = $(this),
                    $valuesHolder = $('input[type="radio"]', $this);
                $('tr input[type="radio"]', $this.closest('tbody')).prop('checked', false);
                $valuesHolder.prop('checked', true);
                $valuesHolder.trigger('change');
                updateForm();
            });
    }

    $('#forms_check-all', $kformPanel).on(
        'change', function () {
            var $this = $(this),
                $formList = $('.js-forms__list');
            $('li:not(:first) > input', $formList).prop('checked', $this.prop('checked'));
            buildAndSendTagValue();
        });

    $formInputs.on('change', updateForm);
    $kformPanel.on('change', $('input[type=checkbox]').not('#forms_check-all'), buildAndSendTagValue);
    bindDataTableRows();

    // Modification mode
    if ($('.js-tabs').tabs().isPanelActive('kform')) {
        buildAndSendTagValue();
    }
})(jQuery.noConflict());
